@@ -1,10 +1,10 @@
 package rubyserver
 
 import (
+	"context"
 	"net"
 	"time"
 
-	"golang.org/x/net/context"
 	"google.golang.org/grpc"
 	healthpb "google.golang.org/grpc/health/grpc_health_v1"
 )
@@ -13,6 +13,9 @@ func ping(address string) error {
 	conn, err := grpc.Dial(
 		address,
 		grpc.WithInsecure(),
+		// Use a custom dialer to ensure that we don't experience
+		// issues in environments that have proxy configurations
+		// https://gitlab.com/gitlab-org/gitaly/merge_requests/1072#note_140408512
 		grpc.WithDialer(func(addr string, timeout time.Duration) (net.Conn, error) {
 			return net.DialTimeout("unix", addr, timeout)
 		}),
