@@ -1,18 +1,20 @@
 package server
 
 import (
+	netctx "context"
+	"crypto/x509"
+	"io/ioutil"
 	"net"
 	"testing"
-	"time"
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"gitlab.com/gitlab-org/gitaly/auth"
+	gitalyauth "gitlab.com/gitlab-org/gitaly/auth"
 	"gitlab.com/gitlab-org/gitaly/internal/config"
 	"gitlab.com/gitlab-org/gitaly/internal/testhelper"
-	netctx "golang.org/x/net/context"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
+	"google.golang.org/grpc/credentials"
 	healthpb "google.golang.org/grpc/health/grpc_health_v1"
 )
 
@@ -30,6 +32,31 @@ func TestSanity(t *testing.T) {
 	require.NoError(t, healthCheck(conn))
 }
 
+func TestTLSSanity(t *testing.T) {
+	srv, addr := runSecureServer(t)
+	defer srv.Stop()
+
+	certPool, err := x509.SystemCertPool()
+	require.NoError(t, err)
+
+	cert, err := ioutil.ReadFile("testdata/gitalycert.pem")
+	require.NoError(t, err)
+
+	ok := certPool.AppendCertsFromPEM(cert)
+	require.True(t, ok)
+
+	creds := credentials.NewClientTLSFromCert(certPool, "")
+	connOpts := []grpc.DialOption{
+		grpc.WithTransportCredentials(creds),
+	}
+
+	conn, err := grpc.Dial(addr, connOpts...)
+	require.NoError(t, err)
+	defer conn.Close()
+
+	require.NoError(t, healthCheck(conn))
+}
+
 func TestAuthFailures(t *testing.T) {
 	defer func(oldAuth config.Auth) {
 		config.Config.Auth = oldAuth
@@ -146,10 +173,6 @@ func (brokenAuth) GetRequestMetadata(netctx.Context, ...string) (map[string]stri
 }
 
 func dial(serverSocketPath string, opts []grpc.DialOption) (*grpc.ClientConn, error) {
-	opts = append(opts, grpc.WithDialer(func(addr string, timeout time.Duration) (net.Conn, error) {
-		return net.DialTimeout("unix", addr, timeout)
-	}))
-
 	return grpc.Dial(serverSocketPath, opts...)
 }
 
@@ -163,7 +186,7 @@ func healthCheck(conn *grpc.ClientConn) error {
 }
 
 func runServer(t *testing.T) (*grpc.Server, string) {
-	srv := New(nil)
+	srv := NewInsecure(nil)
 
 	serverSocketPath := testhelper.GetTemporaryGitalySocketFileName()
 
@@ -171,5 +194,21 @@ func runServer(t *testing.T) (*grpc.Server, string) {
 	require.NoError(t, err)
 	go srv.Serve(listener)
 
-	return srv, serverSocketPath
+	return srv, "unix://" + serverSocketPath
+}
+
+func runSecureServer(t *testing.T) (*grpc.Server, string) {
+	config.Config.TLS = config.TLS{
+		CertPath: "testdata/gitalycert.pem",
+		KeyPath:  "testdata/gitalykey.pem",
+	}
+
+	srv := NewSecure(nil)
+
+	listener, err := net.Listen("tcp", "localhost:9999")
+	require.NoError(t, err)
+
+	go srv.Serve(listener)
+
+	return srv, "localhost:9999"
 }
