@@ -1,11 +1,15 @@
 package server
 
 import (
-	"github.com/grpc-ecosystem/go-grpc-middleware"
-	"github.com/grpc-ecosystem/go-grpc-middleware/logging/logrus"
-	"github.com/grpc-ecosystem/go-grpc-middleware/tags"
-	"github.com/grpc-ecosystem/go-grpc-prometheus"
+	"context"
+	"crypto/tls"
+
+	grpc_middleware "github.com/grpc-ecosystem/go-grpc-middleware"
+	grpc_logrus "github.com/grpc-ecosystem/go-grpc-middleware/logging/logrus"
+	grpc_ctxtags "github.com/grpc-ecosystem/go-grpc-middleware/tags"
+	grpc_prometheus "github.com/grpc-ecosystem/go-grpc-prometheus"
 	log "github.com/sirupsen/logrus"
+	"gitlab.com/gitlab-org/gitaly/internal/config"
 	"gitlab.com/gitlab-org/gitaly/internal/helper/fieldextractors"
 	gitalylog "gitlab.com/gitlab-org/gitaly/internal/log"
 	"gitlab.com/gitlab-org/gitaly/internal/logsanitizer"
@@ -17,8 +21,10 @@ import (
 	"gitlab.com/gitlab-org/gitaly/internal/rubyserver"
 	"gitlab.com/gitlab-org/gitaly/internal/server/auth"
 	"gitlab.com/gitlab-org/gitaly/internal/service"
-	"golang.org/x/net/context"
+	grpccorrelation "gitlab.com/gitlab-org/labkit/correlation/grpc"
+	grpctracing "gitlab.com/gitlab-org/labkit/tracing/grpc"
 	"google.golang.org/grpc"
+	"google.golang.org/grpc/credentials"
 	"google.golang.org/grpc/reflection"
 )
 
@@ -57,17 +63,19 @@ func init() {
 	grpc_logrus.ReplaceGrpcLogger(log.NewEntry(gitalylog.GrpcGo))
 }
 
-// New returns a GRPC server with all Gitaly services and interceptors set up.
-func New(rubyServer *rubyserver.Server) *grpc.Server {
+// createNewServer returns a GRPC server with all Gitaly services and interceptors set up.
+// allows for specifying secure = true to enable tls credentials
+func createNewServer(rubyServer *rubyserver.Server, secure bool) *grpc.Server {
 	ctxTagOpts := []grpc_ctxtags.Option{
 		grpc_ctxtags.WithFieldExtractorForInitialReq(fieldextractors.FieldExtractor),
 	}
 
 	lh := limithandler.New(concurrencyKeyFn)
 
-	server := grpc.NewServer(
+	opts := []grpc.ServerOption{
 		grpc.StreamInterceptor(grpc_middleware.ChainStreamServer(
 			grpc_ctxtags.StreamServerInterceptor(ctxTagOpts...),
+			grpccorrelation.StreamServerCorrelationInterceptor(), // Must be above the metadata handler
 			metadatahandler.StreamInterceptor,
 			grpc_prometheus.StreamServerInterceptor,
 			grpc_logrus.StreamServerInterceptor(logrusEntry),
@@ -75,12 +83,14 @@ func New(rubyServer *rubyserver.Server) *grpc.Server {
 			cancelhandler.Stream, // Should be below LogHandler
 			lh.StreamInterceptor(),
 			auth.StreamServerInterceptor(),
+			grpctracing.StreamServerTracingInterceptor(),
 			// Panic handler should remain last so that application panics will be
 			// converted to errors and logged
 			panichandler.StreamPanicHandler,
 		)),
 		grpc.UnaryInterceptor(grpc_middleware.ChainUnaryServer(
 			grpc_ctxtags.UnaryServerInterceptor(ctxTagOpts...),
+			grpccorrelation.UnaryServerCorrelationInterceptor(), // Must be above the metadata handler
 			metadatahandler.UnaryInterceptor,
 			grpc_prometheus.UnaryServerInterceptor,
 			grpc_logrus.UnaryServerInterceptor(logrusEntry),
@@ -88,11 +98,24 @@ func New(rubyServer *rubyserver.Server) *grpc.Server {
 			cancelhandler.Unary, // Should be below LogHandler
 			lh.UnaryInterceptor(),
 			auth.UnaryServerInterceptor(),
+			grpctracing.UnaryServerTracingInterceptor(),
 			// Panic handler should remain last so that application panics will be
 			// converted to errors and logged
 			panichandler.UnaryPanicHandler,
 		)),
-	)
+	}
+
+	// If tls config is specified attempt to extract tls options and use it
+	// as a grpc.ServerOption
+	if secure {
+		cert, err := tls.LoadX509KeyPair(config.Config.TLS.CertPath, config.Config.TLS.KeyPath)
+		if err != nil {
+			log.Fatal(err)
+		}
+		opts = append(opts, grpc.Creds(credentials.NewServerTLSFromCert(&cert)))
+	}
+
+	server := grpc.NewServer(opts...)
 
 	service.RegisterAll(server, rubyServer)
 	reflection.Register(server)
@@ -101,3 +124,13 @@ func New(rubyServer *rubyserver.Server) *grpc.Server {
 
 	return server
 }
+
+// NewInsecure returns a GRPC server with all Gitaly services and interceptors set up.
+func NewInsecure(rubyServer *rubyserver.Server) *grpc.Server {
+	return createNewServer(rubyServer, false)
+}
+
+// NewSecure returns a GRPC server enabling TLS credentials
+func NewSecure(rubyServer *rubyserver.Server) *grpc.Server {
+	return createNewServer(rubyServer, true)
+}
