@@ -9,6 +9,7 @@ import (
 	"testing"
 
 	"github.com/golang/protobuf/ptypes/timestamp"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/testhelper"
@@ -367,6 +368,52 @@ func TestSuccessfulFindCommitsRequestWithAltGitObjectDirs(t *testing.T) {
 	}
 }
 
+func TestSuccessfulFindCommitsRequestWithAmbiguousRef(t *testing.T) {
+	server, serverSocketPath := startTestServices(t)
+	defer server.Stop()
+
+	client, conn := newCommitServiceClient(t, serverSocketPath)
+	defer conn.Close()
+
+	testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepoWithWorktree(t)
+	defer cleanupFn()
+
+	// These are arbitrary SHAs in the repository. The important part is
+	// that we create a branch using one of them with a different SHA so
+	// that Git detects an ambiguous reference.
+	branchName := "1e292f8fedd741b75372e19097c76d327140c312"
+	commitSha := "6907208d755b60ebeacb2e9dfea74c92c3449a1f"
+
+	testhelper.MustRunCommand(t, nil, "git", "-C", testRepoPath, "checkout", "-b", branchName, commitSha)
+
+	request := &gitalypb.FindCommitsRequest{
+		Repository: testRepo,
+		Revision:   []byte(branchName),
+		Limit:      1,
+	}
+
+	ctx, cancel := testhelper.Context()
+	defer cancel()
+
+	c, err := client.FindCommits(ctx, request)
+	require.NoError(t, err)
+
+	receivedCommits := []*gitalypb.GitCommit{}
+
+	for {
+		resp, err := c.Recv()
+		if err == io.EOF {
+			break
+		} else if err != nil {
+			t.Fatal(err)
+		}
+
+		receivedCommits = append(receivedCommits, resp.GetCommits()...)
+	}
+
+	require.Equal(t, 1, len(receivedCommits), "number of commits received")
+}
+
 func TestFailureFindCommitsRequest(t *testing.T) {
 	server, serverSocketPath := startTestServices(t)
 	defer server.Stop()
@@ -408,3 +455,52 @@ func TestFailureFindCommitsRequest(t *testing.T) {
 		})
 	}
 }
+
+func TestFindCommitsRequestWithFollowAndOffset(t *testing.T) {
+	server, serverSocketPath := startTestServices(t)
+	defer server.Stop()
+
+	client, conn := newCommitServiceClient(t, serverSocketPath)
+	defer conn.Close()
+
+	testRepo, _, cleanupFn := testhelper.NewTestRepo(t)
+	defer cleanupFn()
+
+	request := &gitalypb.FindCommitsRequest{
+		Repository: testRepo,
+		Follow:     true,
+		Paths:      [][]byte{[]byte("CHANGELOG")},
+		Limit:      100,
+	}
+	ctx, cancel := testhelper.Context()
+	defer cancel()
+	allCommits := getCommits(ctx, t, request, client)
+	totalCommits := len(allCommits)
+
+	for offset := 0; offset < totalCommits; offset++ {
+		t.Run(fmt.Sprintf("testing with offset %d", offset), func(t *testing.T) {
+			ctx, cancel := testhelper.Context()
+			defer cancel()
+			request.Offset = int32(offset)
+			request.Limit = int32(totalCommits)
+			commits := getCommits(ctx, t, request, client)
+			assert.Len(t, commits, totalCommits-offset)
+			assert.Equal(t, allCommits[offset:], commits)
+		})
+	}
+}
+
+func getCommits(ctx context.Context, t *testing.T, request *gitalypb.FindCommitsRequest, client gitalypb.CommitServiceClient) []*gitalypb.GitCommit {
+	stream, err := client.FindCommits(ctx, request)
+	require.NoError(t, err)
+
+	var commits []*gitalypb.GitCommit
+	for err == nil {
+		var resp *gitalypb.FindCommitsResponse
+		resp, err = stream.Recv()
+		commits = append(commits, resp.GetCommits()...)
+	}
+
+	require.Equal(t, io.EOF, err)
+	return commits
+}
