@@ -1,45 +1,36 @@
 package ref
 
 import (
+	"context"
+	"fmt"
 	"strings"
 
-	"github.com/grpc-ecosystem/go-grpc-middleware/logging/logrus"
-	log "github.com/sirupsen/logrus"
-	"google.golang.org/grpc/codes"
-	"google.golang.org/grpc/status"
-
-	pb "gitlab.com/gitlab-org/gitaly-proto/go"
+	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/command"
 	"gitlab.com/gitlab-org/gitaly/internal/git"
-	"golang.org/x/net/context"
+	"gitlab.com/gitlab-org/gitaly/internal/helper"
 )
 
 // RefExists returns true if the given reference exists. The ref must start with the string `ref/`
-func (server) RefExists(ctx context.Context, in *pb.RefExistsRequest) (*pb.RefExistsResponse, error) {
+func (server) RefExists(ctx context.Context, in *gitalypb.RefExistsRequest) (*gitalypb.RefExistsResponse, error) {
 	ref := string(in.Ref)
-	exists, err := refExists(ctx, in.Repository, ref)
-	if err != nil {
-		return nil, err
-	}
-
-	return &pb.RefExistsResponse{Value: exists}, nil
-}
-
-func refExists(ctx context.Context, repo *pb.Repository, ref string) (bool, error) {
-	grpc_logrus.Extract(ctx).WithFields(log.Fields{
-		"ref": ref,
-	}).Debug("refExists")
 
 	if !isValidRefName(ref) {
-		return false, status.Errorf(codes.InvalidArgument, "invalid refname")
+		return nil, helper.ErrInvalidArgument(fmt.Errorf("invalid refname"))
 	}
 
+	exists, err := refExists(ctx, in.Repository, ref)
+	if err != nil {
+		return nil, helper.ErrInternal(err)
+	}
+
+	return &gitalypb.RefExistsResponse{Value: exists}, nil
+}
+
+func refExists(ctx context.Context, repo *gitalypb.Repository, ref string) (bool, error) {
 	cmd, err := git.Command(ctx, repo, "show-ref", "--verify", "--quiet", ref)
 	if err != nil {
-		if _, ok := status.FromError(err); ok {
-			return false, err
-		}
-		return false, status.Errorf(codes.Internal, err.Error())
+		return false, err
 	}
 
 	err = cmd.Wait()
@@ -54,7 +45,7 @@ func refExists(ctx context.Context, repo *pb.Repository, ref string) (bool, erro
 	}
 
 	// This will normally occur when exit code > 1
-	return false, status.Errorf(codes.Internal, err.Error())
+	return false, err
 }
 
 func isValidRefName(refName string) bool {
