@@ -3,6 +3,7 @@ package repository
 import (
 	"bufio"
 	"bytes"
+	"context"
 	"crypto/sha1"
 	"encoding/hex"
 	"math/big"
@@ -13,7 +14,6 @@ import (
 	"gitlab.com/gitlab-org/gitaly/internal/git"
 	"gitlab.com/gitlab-org/gitaly/internal/git/alternates"
 	"gitlab.com/gitlab-org/gitaly/internal/helper"
-	"golang.org/x/net/context"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 )
@@ -71,7 +71,7 @@ func (s *server) CalculateChecksum(ctx context.Context, in *gitalypb.CalculateCh
 		return nil, status.Errorf(codes.Internal, err.Error())
 	}
 
-	if err := cmd.Wait(); err != nil {
+	if err := cmd.Wait(); checksum == nil || err != nil {
 		if isValidRepo(ctx, repo) {
 			return &gitalypb.CalculateChecksumResponse{Checksum: blankChecksum}, nil
 		}
