@@ -1,6 +1,7 @@
 package repository
 
 import (
+	"context"
 	"os"
 	"path"
 	"testing"
@@ -9,7 +10,6 @@ import (
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/config"
 	"gitlab.com/gitlab-org/gitaly/internal/testhelper"
-	"golang.org/x/net/context"
 	"google.golang.org/grpc/codes"
 )
 
