@@ -7,7 +7,6 @@ import (
 	"path"
 	"strings"
 	"testing"
-	"time"
 
 	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/require"
@@ -21,9 +20,10 @@ import (
 )
 
 type createWikiPageOpts struct {
-	title   string
-	content []byte
-	format  string
+	title             string
+	content           []byte
+	format            string
+	forceContentEmpty bool
 }
 
 var (
@@ -64,15 +64,12 @@ func runWikiServiceServer(t *testing.T) (*grpc.Server, string) {
 
 	go grpcServer.Serve(listener)
 
-	return grpcServer, serverSocketPath
+	return grpcServer, "unix://" + serverSocketPath
 }
 
 func newWikiClient(t *testing.T, serverSocketPath string) (gitalypb.WikiServiceClient, *grpc.ClientConn) {
 	connOpts := []grpc.DialOption{
 		grpc.WithInsecure(),
-		grpc.WithDialer(func(addr string, timeout time.Duration) (net.Conn, error) {
-			return net.DialTimeout("unix", addr, timeout)
-		}),
 	}
 	conn, err := grpc.Dial(serverSocketPath, connOpts...)
 	if err != nil {
@@ -84,7 +81,7 @@ func newWikiClient(t *testing.T, serverSocketPath string) (gitalypb.WikiServiceC
 
 func writeWikiPage(t *testing.T, client gitalypb.WikiServiceClient, wikiRepo *gitalypb.Repository, opts createWikiPageOpts) {
 	var content []byte
-	if len(opts.content) == 0 {
+	if len(opts.content) == 0 && !opts.forceContentEmpty {
 		content = mockPageContent
 	} else {
 		content = opts.content
@@ -192,7 +189,6 @@ func createTestWikiPage(t *testing.T, client gitalypb.WikiServiceClient, wikiRep
 
 	wikiRepoPath, err := helper.GetRepoPath(wikiRepo)
 	require.NoError(t, err)
-
 	writeWikiPage(t, client, wikiRepo, opts)
 	head1ID := testhelper.MustRunCommand(t, nil, "git", "-C", wikiRepoPath, "show", "--format=format:%H", "--no-patch", "HEAD")
 	pageCommit, err := gitlog.GetCommit(ctx, wikiRepo, string(head1ID))
