@@ -18,14 +18,16 @@ import (
 	"testing"
 	"time"
 
-	"github.com/grpc-ecosystem/go-grpc-middleware"
-	"github.com/grpc-ecosystem/go-grpc-middleware/logging/logrus"
+	grpc_middleware "github.com/grpc-ecosystem/go-grpc-middleware"
+	grpc_logrus "github.com/grpc-ecosystem/go-grpc-middleware/logging/logrus"
+	grpc_ctxtags "github.com/grpc-ecosystem/go-grpc-middleware/tags"
 	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/command"
 	"gitlab.com/gitlab-org/gitaly/internal/config"
+	"gitlab.com/gitlab-org/gitaly/internal/helper/fieldextractors"
 	gitalylog "gitlab.com/gitlab-org/gitaly/internal/log"
 	"gitlab.com/gitlab-org/gitaly/internal/storage"
 	"google.golang.org/grpc"
@@ -86,7 +88,7 @@ func GitlabTestStoragePath() string {
 func GitalyServersMetadata(t *testing.T, serverSocketPath string) metadata.MD {
 	gitalyServers := storage.GitalyServers{
 		"default": {
-			"address": "unix:" + serverSocketPath,
+			"address": serverSocketPath,
 			"token":   RepositoryAuthToken,
 		},
 	}
@@ -187,19 +189,19 @@ func AuthorsEqual(a *gitalypb.CommitAuthor, b *gitalypb.CommitAuthor) bool {
 // GitCommitEqual tests if two `GitCommit`s are equal
 func GitCommitEqual(a, b *gitalypb.GitCommit) error {
 	if !authorSortofEqual(a.GetAuthor(), b.GetAuthor()) {
-		return fmt.Errorf("Author does not match: %v != %v", a.GetAuthor(), b.GetAuthor())
+		return fmt.Errorf("author does not match: %v != %v", a.GetAuthor(), b.GetAuthor())
 	}
 	if !authorSortofEqual(a.GetCommitter(), b.GetCommitter()) {
-		return fmt.Errorf("Commiter does not match: %v != %v", a.GetCommitter(), b.GetCommitter())
+		return fmt.Errorf("commiter does not match: %v != %v", a.GetCommitter(), b.GetCommitter())
 	}
 	if !bytes.Equal(a.GetBody(), b.GetBody()) {
-		return fmt.Errorf("Body differs: %q != %q", a.GetBody(), b.GetBody())
+		return fmt.Errorf("body differs: %q != %q", a.GetBody(), b.GetBody())
 	}
 	if !bytes.Equal(a.GetSubject(), b.GetSubject()) {
-		return fmt.Errorf("Subject differs: %q != %q", a.GetSubject(), b.GetSubject())
+		return fmt.Errorf("subject differs: %q != %q", a.GetSubject(), b.GetSubject())
 	}
 	if strings.Compare(a.GetId(), b.GetId()) != 0 {
-		return fmt.Errorf("Id does not match: %q != %q", a.GetId(), b.GetId())
+		return fmt.Errorf("id does not match: %q != %q", a.GetId(), b.GetId())
 	}
 	if len(a.GetParentIds()) != len(b.GetParentIds()) {
 		return fmt.Errorf("ParentId does not match: %v != %v", a.GetParentIds(), b.GetParentIds())
@@ -279,8 +281,13 @@ func NewTestGrpcServer(t *testing.T, streamInterceptors []grpc.StreamServerInter
 	logger := NewTestLogger(t)
 	logrusEntry := log.NewEntry(logger).WithField("test", t.Name())
 
-	streamInterceptors = append([]grpc.StreamServerInterceptor{grpc_logrus.StreamServerInterceptor(logrusEntry)}, streamInterceptors...)
-	unaryInterceptors = append([]grpc.UnaryServerInterceptor{grpc_logrus.UnaryServerInterceptor(logrusEntry)}, unaryInterceptors...)
+	ctxTagger := grpc_ctxtags.WithFieldExtractorForInitialReq(fieldextractors.FieldExtractor)
+	ctxStreamTagger := grpc_ctxtags.StreamServerInterceptor(ctxTagger)
+	ctxUnaryTagger := grpc_ctxtags.UnaryServerInterceptor(ctxTagger)
+
+	streamInterceptors = append([]grpc.StreamServerInterceptor{ctxStreamTagger, grpc_logrus.StreamServerInterceptor(logrusEntry)}, streamInterceptors...)
+	unaryInterceptors = append([]grpc.UnaryServerInterceptor{ctxUnaryTagger, grpc_logrus.UnaryServerInterceptor(logrusEntry)}, unaryInterceptors...)
+
 	return grpc.NewServer(
 		grpc.StreamInterceptor(grpc_middleware.ChainStreamServer(streamInterceptors...)),
 		grpc.UnaryInterceptor(grpc_middleware.ChainUnaryServer(unaryInterceptors...)),
@@ -349,7 +356,7 @@ func createRepo(t *testing.T, storagePath string) (repo *gitalypb.Repository, re
 	require.NoError(t, err)
 	relativePath, err = filepath.Rel(storagePath, repoPath)
 	require.NoError(t, err)
-	repo = &gitalypb.Repository{StorageName: "default", RelativePath: relativePath}
+	repo = &gitalypb.Repository{StorageName: "default", RelativePath: relativePath, GlRepository: "project-1"}
 
 	return repo, repoPath, relativePath
 }
