@@ -73,14 +73,5 @@ module GitalyServer
     def sanitize_url(str)
       str.gsub(URL_HOST_PATTERN, '\1[FILTERED]@\3\4')
     end
-
-    def bridge_exceptions
-      yield
-    rescue GRPC::BadStatus => e
-      # Pass GRPC back without wrapping
-      raise e
-    rescue StandardError => e
-      raise GRPC::Unknown.new(e.message, "gitaly-ruby.exception.class": e.class.name)
-    end
   end
 end
