@@ -24,7 +24,6 @@ module Gitlab
       SQUASH_WORKTREE_PREFIX = 'squash'.freeze
       AM_WORKTREE_PREFIX = 'am'.freeze
       GITALY_INTERNAL_URL = 'ssh://gitaly/internal.git'.freeze
-      GITLAB_PROJECTS_TIMEOUT = Gitlab.config.gitlab_shell.git_timeout
       AUTOCRLF_VALUES = { 'true' => true, 'false' => false, 'input' => :input }.freeze
       RUGGED_KEY = :rugged_list
 
@@ -262,8 +261,7 @@ module Gitlab
         false
       end
 
-      # old_rev and new_rev are commit ID's
-      # the result of this method is an array of Gitlab::Git::RawDiffChange
+      # TODO: remove after 11.8 because of https://gitlab.com/gitlab-org/gitaly/merge_requests/1026
       def raw_changes_between(old_rev, new_rev)
         @raw_changes_between ||= {}
 
@@ -295,6 +293,7 @@ module Gitlab
         raise Gitlab::Git::Repository::GitError, e.to_s
       end
 
+      # TODO: remove after 11.8 because of https://gitlab.com/gitlab-org/gitaly/merge_requests/1026
       def parse_raw_diff_line(line)
         old_mode, new_mode, old_blob_id, new_blob_id, rest = line.split(/\s/, 5)
 
@@ -451,7 +450,7 @@ module Gitlab
         with_worktree(rebase_path, branch, env: env) do
           run_git!(
             %W[pull --rebase #{remote_repo_path} #{remote_branch}],
-            chdir: rebase_path, env: env
+            chdir: rebase_path, env: env, include_stderr: true
           )
 
           rebase_sha = run_git!(%w[rev-parse HEAD], chdir: rebase_path, env: env).strip
@@ -476,13 +475,13 @@ module Gitlab
         with_worktree(squash_path, branch, sparse_checkout_files: diff_files, env: env) do
           # Apply diff of the `diff_range` to the worktree
           diff = run_git!(%W[diff --binary #{diff_range}])
-          run_git!(%w[apply --index --whitespace=nowarn], chdir: squash_path, env: env) do |stdin|
+          run_git!(%w[apply --index --whitespace=nowarn], chdir: squash_path, env: env, include_stderr: true) do |stdin|
             stdin.binmode
             stdin.write(diff)
           end
 
           # Commit the `diff_range` diff
-          run_git!(%W[commit --no-verify --message #{message}], chdir: squash_path, env: env)
+          run_git!(%W[commit --no-verify --message #{message}], chdir: squash_path, env: env, include_stderr: true)
 
           # Return the squash sha. May print a warning for ambiguous refs, but
           # we can ignore that with `--quiet` and just take the SHA, if present.
@@ -537,18 +536,6 @@ module Gitlab
         end
       end
 
-      def push_remote_branches(remote_name, branch_names, forced: true)
-        success = @gitlab_projects.push_branches(remote_name, GITLAB_PROJECTS_TIMEOUT, forced, branch_names)
-
-        success || gitlab_projects_error
-      end
-
-      def delete_remote_branches(remote_name, branch_names)
-        success = @gitlab_projects.delete_remote_branches(remote_name, branch_names)
-
-        success || gitlab_projects_error
-      end
-
       def multi_action(
         user, branch_name:, message:, actions:,
         author_email: nil, author_name: nil,
@@ -710,11 +697,16 @@ module Gitlab
         Gitlab::Git.committer_hash(email: user.email, name: user.name)
       end
 
-      def write_ref(ref_path, ref, old_ref: nil, shell: true)
-        if shell
-          shell_write_ref(ref_path, ref, old_ref)
+      def write_ref(ref_path, ref, old_ref: nil)
+        raise ArgumentError, "invalid ref_path #{ref_path.inspect}" if ref_path.include?(' ')
+        raise ArgumentError, "invalid ref #{ref.inspect}" if ref.include?("\x00")
+        raise ArgumentError, "invalid old_ref #{old_ref.inspect}" if !old_ref.nil? && old_ref.include?("\x00")
+
+        if ref_path == 'HEAD'
+          run_git!(%W[symbolic-ref #{ref_path} #{ref}])
         else
-          rugged_write_ref(ref_path, ref)
+          input = "update #{ref_path}\x00#{ref}\x00#{old_ref}\x00"
+          run_git!(%w[update-ref --stdin -z]) { |stdin| stdin.write(input) }
         end
       end
 
@@ -723,7 +715,7 @@ module Gitlab
         source_repository = RemoteRepository.new(source_repository) unless source_repository.is_a?(RemoteRepository)
 
         args = %W[fetch --no-tags -f #{GITALY_INTERNAL_URL} #{source_ref}:#{target_ref}]
-        message, status = run_git(args, env: source_repository.fetch_env)
+        message, status = run_git(args, env: source_repository.fetch_env, include_stderr: true)
         raise Gitlab::Git::CommandError, message if status != 0
 
         target_ref
@@ -846,18 +838,18 @@ module Gitlab
 
       private
 
-      def run_git(args, chdir: path, env: {}, nice: false, lazy_block: nil, &block)
+      def run_git(args, chdir: path, env: {}, nice: false, include_stderr: false, lazy_block: nil, &block)
         cmd = [Gitlab.config.git.bin_path, *args]
         cmd.unshift("nice") if nice
 
         object_directories = alternate_object_directories
         env['GIT_ALTERNATE_OBJECT_DIRECTORIES'] = object_directories.join(File::PATH_SEPARATOR) if object_directories.any?
 
-        popen(cmd, chdir, env, lazy_block: lazy_block, &block)
+        popen(cmd, chdir, env, include_stderr: include_stderr, lazy_block: lazy_block, &block)
       end
 
-      def run_git!(args, chdir: path, env: {}, nice: false, lazy_block: nil, &block)
-        output, status = run_git(args, chdir: chdir, env: env, nice: nice, lazy_block: lazy_block, &block)
+      def run_git!(args, chdir: path, env: {}, nice: false, include_stderr: false, lazy_block: nil, &block)
+        output, status = run_git(args, chdir: chdir, env: env, nice: nice, include_stderr: include_stderr, lazy_block: lazy_block, &block)
 
         raise GitError, output unless status.zero?
 
@@ -928,7 +920,8 @@ module Gitlab
           cmd += Array(options[:path])
         end
 
-        raw_output, _status = run_git(cmd)
+        # Disable stderr because Git can show warnings that corrupt the output stream
+        raw_output, _status = run_git(cmd, include_stderr: false)
         lines = offset_in_ruby ? raw_output.lines.drop(offset) : raw_output.lines
 
         lines.map! { |c| Rugged::Commit.new(rugged, c.strip) }
@@ -948,6 +941,7 @@ module Gitlab
         ]
       end
 
+      # TODO: remove after 11.8 because of https://gitlab.com/gitlab-org/gitaly/merge_requests/1026
       def git_diff_cmd(old_rev, new_rev)
         old_rev = old_rev == ::Gitlab::Git::BLANK_SHA ? ::Gitlab::Git::EMPTY_TREE_ID : old_rev
 
@@ -964,7 +958,7 @@ module Gitlab
           "delete #{ref}\x00\x00"
         end
 
-        message, status = run_git(%w[update-ref --stdin -z]) do |stdin|
+        message, status = run_git(%w[update-ref --stdin -z], include_stderr: true) do |stdin|
           stdin.write(instructions.join)
         end
 
@@ -1016,25 +1010,6 @@ module Gitlab
         Rugged::Commit.create(rugged, params)
       end
 
-      def shell_write_ref(ref_path, ref, old_ref)
-        raise ArgumentError, "invalid ref_path #{ref_path.inspect}" if ref_path.include?(' ')
-        raise ArgumentError, "invalid ref #{ref.inspect}" if ref.include?("\x00")
-        raise ArgumentError, "invalid old_ref #{old_ref.inspect}" if !old_ref.nil? && old_ref.include?("\x00")
-
-        input = "update #{ref_path}\x00#{ref}\x00#{old_ref}\x00"
-        run_git!(%w[update-ref --stdin -z]) { |stdin| stdin.write(input) }
-      end
-
-      def rugged_write_ref(ref_path, ref)
-        rugged.references.create(ref_path, ref, force: true)
-      rescue Rugged::ReferenceError => ex
-        Rails.logger.error "Unable to create #{ref_path} reference for repository #{path}: #{ex}"
-      rescue Rugged::OSError => ex
-        raise unless ex.message =~ /Failed to create locked file/ && ex.message =~ /File exists/
-
-        Rails.logger.error "Unable to create #{ref_path} reference for repository #{path}: #{ex}"
-      end
-
       def rugged_head
         rugged.head
       rescue Rugged::ReferenceError
@@ -1072,7 +1047,7 @@ module Gitlab
       # this can be very expensive, so set up sparse checkout for the worktree
       # to only check out the files we're interested in.
       def configure_sparse_checkout(worktree_git_path, files)
-        run_git!(%w[config core.sparseCheckout true])
+        run_git!(%w[config core.sparseCheckout true], include_stderr: true)
 
         return if files.empty?
 
