@@ -23,15 +23,6 @@ describe Gitlab::Git::Repository do # rubocop:disable Metrics/BlockLength
       }
     end
     let(:call) { double(metadata: call_metadata) }
-    let(:gitlab_shell_path) { '/foo/bar/gitlab-shell' }
-
-    before do
-      ENV['GITALY_RUBY_GITLAB_SHELL_PATH'] = gitlab_shell_path
-    end
-
-    after do
-      ENV.delete('GITALY_RUBY_GITLAB_SHELL_PATH')
-    end
 
     it 'cleans up the repository' do
       described_class.from_gitaly_with_block(test_repo_read_only, call) do |repository|
@@ -382,6 +373,8 @@ describe Gitlab::Git::Repository do # rubocop:disable Metrics/BlockLength
   end
 
   describe '#write_ref' do
+    let(:repository) { mutable_repository }
+
     context 'validations' do
       using RSpec::Parameterized::TableSyntax
 
@@ -396,6 +389,19 @@ describe Gitlab::Git::Repository do # rubocop:disable Metrics/BlockLength
         end
       end
     end
+
+    it 'writes the HEAD' do
+      repository.write_ref('HEAD', 'refs/heads/feature')
+
+      expect(repository.commit('HEAD')).to eq(repository.commit('feature'))
+      expect(repository.root_ref).to eq('feature')
+    end
+
+    it 'writes other refs' do
+      repository.write_ref('refs/heads/feature', SeedRepo::Commit::ID)
+
+      expect(repository.commit('feature').sha).to eq(SeedRepo::Commit::ID)
+    end
   end
 
   describe '#write_config' do
